==> eam-wshub-proxyclient-11.4-9-sources.jar: net/datastream/schemas/mp_functions/gridrequest/ObjectFactory.java <==

package net.datastream.schemas.mp_functions.gridrequest;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_functions.gridrequest package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_functions.gridrequest
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link MULTIADDON_FILTERS }
     * 
     */
    public MULTIADDON_FILTERS createMULTIADDON_FILTERS() {
        return new MULTIADDON_FILTERS();
    }

    /**
     * Create an instance of {@link LOV }
     * 
     */
    public LOV createLOV() {
        return new LOV();
    }

    /**
     * Create an instance of {@link LOV.LOV_PARAMETERS }
     * 
     */
    public LOV.LOV_PARAMETERS createLOVLOV_PARAMETERS() {
        return new LOV.LOV_PARAMETERS();
    }

    /**
     * Create an instance of {@link GRID }
     * 
     */
    public GRID createGRID() {
        return new GRID();
    }

    /**
     * Create an instance of {@link ADDON_SORT }
     * 
     */
    public ADDON_SORT createADDON_SORT() {
        return new ADDON_SORT();
    }

    /**
     * Create an instance of {@link ADDON_FILTER }
     * 
     */
    public ADDON_FILTER createADDON_FILTER() {
        return new ADDON_FILTER();
    }

    /**
     * Create an instance of {@link MULTIADDON_FILTERS.MADDON_FILTER }
     * 
     */
    public MULTIADDON_FILTERS.MADDON_FILTER createMULTIADDON_FILTERSMADDON_FILTER() {
        return new MULTIADDON_FILTERS.MADDON_FILTER();
    }

    /**
     * Create an instance of {@link GRID_TYPE }
     * 
     */
    public GRID_TYPE createGRID_TYPE() {
        return new GRID_TYPE();
    }

    /**
     * Create an instance of {@link DATASPY }
     * 
     */
    public DATASPY createDATASPY() {
        return new DATASPY();
    }

    /**
     * Create an instance of {@link PROMPTFIELD }
     * 
     */
    public PROMPTFIELD createPROMPTFIELD() {
        return new PROMPTFIELD();
    }

    /**
     * Create an instance of {@link LOV.LOV_PARAMETERS.LOV_PARAMETER }
     * 
     */
    public LOV.LOV_PARAMETERS.LOV_PARAMETER createLOVLOV_PARAMETERSLOV_PARAMETER() {
        return new LOV.LOV_PARAMETERS.LOV_PARAMETER();
    }

}

==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_functions/gridrequest/ObjectFactory.java <==

package net.datastream.schemas.mp_functions.gridrequest;

import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_functions.gridrequest package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_functions.gridrequest
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link MULTIADDON_FILTERS }
     * 
     * @return
     *     the new instance of {@link MULTIADDON_FILTERS }
     */
    public MULTIADDON_FILTERS createMULTIADDON_FILTERS() {
        return new MULTIADDON_FILTERS();
    }

    /**
     * Create an instance of {@link LOV }
     * 
     * @return
     *     the new instance of {@link LOV }
     */
    public LOV createLOV() {
        return new LOV();
    }

    /**
     * Create an instance of {@link LOV.LOV_PARAMETERS }
     * 
     * @return
     *     the new instance of {@link LOV.LOV_PARAMETERS }
     */
    public LOV.LOV_PARAMETERS createLOVLOV_PARAMETERS() {
        return new LOV.LOV_PARAMETERS();
    }

    /**
     * Create an instance of {@link GRID }
     * 
     * @return
     *     the new instance of {@link GRID }
     */
    public GRID createGRID() {
        return new GRID();
    }

    /**
     * Create an instance of {@link ADDON_SORT }
     * 
     * @return
     *     the new instance of {@link ADDON_SORT }
     */
    public ADDON_SORT createADDON_SORT() {
        return new ADDON_SORT();
    }

    /**
     * Create an instance of {@link ADDON_FILTER }
     * 
     * @return
     *     the new instance of {@link ADDON_FILTER }
     */
    public ADDON_FILTER createADDON_FILTER() {
        return new ADDON_FILTER();
    }

    /**
     * Create an instance of {@link MULTIADDON_FILTERS.MADDON_FILTER }
     * 
     * @return
     *     the new instance of {@link MULTIADDON_FILTERS.MADDON_FILTER }
     */
    public MULTIADDON_FILTERS.MADDON_FILTER createMULTIADDON_FILTERSMADDON_FILTER() {
        return new MULTIADDON_FILTERS.MADDON_FILTER();
    }

    /**
     * Create an instance of {@link GRID_TYPE }
     * 
     * @return
     *     the new instance of {@link GRID_TYPE }
     */
    public GRID_TYPE createGRID_TYPE() {
        return new GRID_TYPE();
    }

    /**
     * Create an instance of {@link DATASPY }
     * 
     * @return
     *     the new instance of {@link DATASPY }
     */
    public DATASPY createDATASPY() {
        return new DATASPY();
    }

    /**
     * Create an instance of {@link PROMPTFIELD }
     * 
     * @return
     *     the new instance of {@link PROMPTFIELD }
     */
    public PROMPTFIELD createPROMPTFIELD() {
        return new PROMPTFIELD();
    }

    /**
     * Create an instance of {@link LOV.LOV_PARAMETERS.LOV_PARAMETER }
     * 
     * @return
     *     the new instance of {@link LOV.LOV_PARAMETERS.LOV_PARAMETER }
     */
    public LOV.LOV_PARAMETERS.LOV_PARAMETER createLOVLOV_PARAMETERSLOV_PARAMETER() {
        return new LOV.LOV_PARAMETERS.LOV_PARAMETER();
    }

}
